@@ -2,7 +2,7 @@
 
 import sys
 import requests
-import .data_sources as ds
+from .datasources import KNOWN_DATASETS
 
 UNIPROT_URL = 'http://uniprot.org/uniprot/'
 
@@ -20,7 +20,7 @@ class UnknownDataSetError(BaseException):
 def format_url(uid: str, data_format='fasta', dataset='default'):
     if dataset == 'default':
         return UNIPROT_URL + uid + '/.' + data_format
-    elif dataset in ds.KNOWN_DATASETS:
+    elif dataset in KNOWN_DATASETS:
         return BASE_API_URL + dataset + '/' + uid + '/.' + data_format 
     else:
         raise UnknownDataSetError()
