@@ -11,12 +11,12 @@ def _write_to_file(uid: str, content: str):
 
 
 def fetch_and_save(uid: str, data_format='fasta', dataset='default'):
-    print(f"Searching dataset={dataset} on uniprot for {uniprot_id}...")
+    print(f"Searching dataset={dataset} on uniprot for {uid}...")
     try:
-        content = fetch(uniprot_id)
-        print(f"Found result for {uniprot_id}. "
+        content = fetch(uid)
+        print(f"Found result for {uid}. "
                 f"Printing to file with format '.{data_format}'...")
-        _write_to_file(uniprot_id, content)
+        _write_to_file(uid, content)
         print('Done.')
     except EntryNotFoundException:
-        print(f"No protein found for ID: {uniprot_id}")
+        print(f"No protein found for ID: {uid}")
